# nt25.py

Neo's Tools of Python in 2025

## TODO

- [x] fio
- [x] sqlite
- [x] ex: EXIF tools with Magic
- [x] mt: MapXYZ Transfer tool
- [x] pgogs: Purge Gogs orphan files
- [ ] mysql
- [ ] redis

## Usage

```sh
# help of exif
ex -h

# help of MapXYZ
mt -h

# Purge Gogs orphan files
./pgogs
```

## fun

$$
\sqrt{-1},2^{3},\sum,\pi
$$
